==> kubernetes-model-batch-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/UncountedTerminatedPodsFluent.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface UncountedTerminatedPodsFluent<A extends UncountedTerminatedPodsFluent<A>> extends Fluent<A>{
  public A addToFailed(Integer index,String item);
  public A setToFailed(Integer index,String item);
  public A addToFailed(java.lang.String... items);
  public A addAllToFailed(Collection<String> items);
  public A removeFromFailed(java.lang.String... items);
  public A removeAllFromFailed(Collection<String> items);
  public List<String> getFailed();
  public String getFailed(Integer index);
  public String getFirstFailed();
  public String getLastFailed();
  public String getMatchingFailed(Predicate<String> predicate);
  public Boolean hasMatchingFailed(Predicate<String> predicate);
  public A withFailed(List<String> failed);
  public A withFailed(java.lang.String... failed);
  public Boolean hasFailed();
  public A addToSucceeded(Integer index,String item);
  public A setToSucceeded(Integer index,String item);
  public A addToSucceeded(java.lang.String... items);
  public A addAllToSucceeded(Collection<String> items);
  public A removeFromSucceeded(java.lang.String... items);
  public A removeAllFromSucceeded(Collection<String> items);
  public List<String> getSucceeded();
  public String getSucceeded(Integer index);
  public String getFirstSucceeded();
  public String getLastSucceeded();
  public String getMatchingSucceeded(Predicate<String> predicate);
  public Boolean hasMatchingSucceeded(Predicate<String> predicate);
  public A withSucceeded(List<String> succeeded);
  public A withSucceeded(java.lang.String... succeeded);
  public Boolean hasSucceeded();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> kubernetes-model-batch-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/UncountedTerminatedPodsFluent.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface UncountedTerminatedPodsFluent<A extends UncountedTerminatedPodsFluent<A>> extends Fluent<A>{
  public A addToFailed(int index,String item);
  public A setToFailed(int index,String item);
  public A addToFailed(java.lang.String... items);
  public A addAllToFailed(Collection<String> items);
  public A removeFromFailed(java.lang.String... items);
  public A removeAllFromFailed(Collection<String> items);
  public List<String> getFailed();
  public String getFailed(int index);
  public String getFirstFailed();
  public String getLastFailed();
  public String getMatchingFailed(Predicate<String> predicate);
  public Boolean hasMatchingFailed(Predicate<String> predicate);
  public A withFailed(List<String> failed);
  public A withFailed(java.lang.String... failed);
  public Boolean hasFailed();
  public A addToSucceeded(int index,String item);
  public A setToSucceeded(int index,String item);
  public A addToSucceeded(java.lang.String... items);
  public A addAllToSucceeded(Collection<String> items);
  public A removeFromSucceeded(java.lang.String... items);
  public A removeAllFromSucceeded(Collection<String> items);
  public List<String> getSucceeded();
  public String getSucceeded(int index);
  public String getFirstSucceeded();
  public String getLastSucceeded();
  public String getMatchingSucceeded(Predicate<String> predicate);
  public Boolean hasMatchingSucceeded(Predicate<String> predicate);
  public A withSucceeded(List<String> succeeded);
  public A withSucceeded(java.lang.String... succeeded);
  public Boolean hasSucceeded();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
